@@ -1,6 +1,6 @@
 use warnings;
 use strict;
-package Test::Module 0.20180802; # TRIAL
+package Test::Module 0.20180803; # TRIAL
 
 # ABSTRACT: brief summary of what this module is used for
 
@@ -9,6 +9,12 @@ our (@EXPORT_OK) = ();
 our (@EXPORT)    = (@EXPORT_OK);
 
 
+
+sub new {
+    my $pkg = shift;
+    bless {}, $pkg;
+}
+
 1;
 
 __END__
@@ -23,13 +29,20 @@ Test::Module - brief summary of what this module is used for
 
 =head1 VERSION
 
-version 0.20180802
+version 0.20180803
 
 =head1 SYNOPSIS
 
     use Test::Module;
 
-    ## ... code that uses your package
+    my $obj = new Test::Module;
+    print "Hello World\n" if $obj->isa('Test::Modules');
+
+=head1 METHODS
+
+=head2 new
+
+Takes no arguments. Returns a blessed reference.
 
 =head1 AUTHOR
 
